@@ -17,7 +17,7 @@
 
 """GTK user interface for the Gaupol subtitle editor."""
 
-__version__ = "1.9"
+__version__ = "1.12"
 COMBO_SEPARATOR = "<separator/>"
 
 import sys
@@ -28,6 +28,12 @@ if hasattr(sys, "frozen"):
     # https://stackoverflow.com/a/35773092
     warnings.simplefilter("ignore")
 
+# Needed for the spell-check dialog, where the '_proceed' function call is
+# recursive. The recursion limit effectively defines the maximum allowed
+# amount of consecutive subtitles without spelling errors, which if exceeded
+# triggers a RecursionError.
+sys.setrecursionlimit(10000)
+
 import aeidon
 import gi
 import os
