@@ -20,6 +20,7 @@
 import aeidon
 import gaupol
 import linecache
+import os
 import platform
 import sys
 import traceback
@@ -65,7 +66,7 @@ class DebugDialog(Gtk.MessageDialog):
         self._text_view.set_left_margin(6)
         self._text_view.set_right_margin(6)
         with aeidon.util.silent(AttributeError):
-            # Top and bottom margins available since GTK+ 3.18.
+            # Top and bottom margins available since GTK 3.18.
             self._text_view.set_top_margin(6)
             self._text_view.set_bottom_margin(6)
         text_buffer = self._text_view.get_buffer()
@@ -84,14 +85,19 @@ class DebugDialog(Gtk.MessageDialog):
         """Insert information about user's platform and environment."""
         locale = aeidon.locales.get_system_code()
         encoding = aeidon.encodings.get_locale_code()
+        wayland = "yes" if (
+            os.getenv("XDG_SESSION_TYPE", "") == "wayland" or
+            os.getenv("WAYLAND_DISPLAY", "")
+        ) else "no"
         self._insert_text("Platform: {}\n".format(platform.platform(True)))
-        self._insert_text("Locale: {}.{}\n\n".format(locale, encoding))
+        self._insert_text("Locale: {}.{}\n".format(locale, encoding))
+        self._insert_text("Wayland: {}\n\n".format(wayland))
 
     def _insert_dependencies(self):
         """Insert version numbers of selected dependencies."""
         dotjoin = lambda x: ".".join(map(str, x))
         chardet_version = aeidon.util.get_chardet_version()
-        enchant_version = aeidon.util.get_enchant_version()
+        gspell_version = gaupol.util.get_gspell_version()
         gst_version = gaupol.util.get_gst_version()
         gtk_version = dotjoin((
             Gtk.get_major_version(),
@@ -102,8 +108,8 @@ class DebugDialog(Gtk.MessageDialog):
         python_version = dotjoin(sys.version_info[:3])
         self._insert_text("aeidon: {}\n".format(aeidon.__version__))
         self._insert_text("chardet: {}\n".format(chardet_version))
-        self._insert_text("enchant: {}\n".format(enchant_version))
         self._insert_text("gaupol: {}\n".format(gaupol.__version__))
+        self._insert_text("gspell: {}\n".format(gspell_version))
         self._insert_text("gstreamer: {}\n".format(gst_version))
         self._insert_text("gtk+: {}\n".format(gtk_version))
         self._insert_text("pygobject: {}\n".format(pygobject_version))
